==> libstdc%2B%2B-2.90.3.tar.bz2: libstdc++-2.90.3/bits/std_locale.h <==
// Locale support -*- C++ -*-

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882: 22.1  Locales
//

#ifndef _CPP_LOCALE
#define _CPP_LOCALE	1

#include <bits/c++config.h>  /* C++ Compiler characteristics */
#include <bits/stl_config.h> 
#include <bits/std_climits.h>
#include <bits/utility.h>
#include <bits/std_cstddef.h>  /* size_t */
#include <bits/std_exception.h>
#include <bits/std_iosfwd.h>
#include <bits/missing.h>
#include <bits/std_iterator.h>
#include <bits/std_cwchar.h>
#include <bits/std_memory.h>
#include <bits/stl_string_fwd.h>
#include <bits/char_traits.h>
#include <bits/basic_string.h>      /* but not <bits/basic_string.tcc> */
#include <bits/std_stdexcept.h>
#include <bits/std_vector.h>
#include <bits/std_cctype.h>
#include <bits/std_typeinfo.h> /* for bad_cast */
#include <bits/loccore.h>

#include <bits/std_ctime.h>
#include <bits/ios_base.h>
#include <bits/std_iterator.h>
#include <bits/locfacets.h>

#ifdef _G_NO_TEMPLATE_EXPORT
# define export
# include <bits/std_limits.h>  // numeric_limits<unsigned long>::digits10
# include <bits/std_stdexcept.h>
# include <bits/std_istream.h>
# include <bits/loccore.tcc>
# include <bits/locfacets.tcc>
# include <bits/string.tcc>
#endif

#endif

// Local Variables:
// mode:c++
// End:

==> libstdc%2B%2B-2.90.5.tar.bz2: libstdc++-2.90.5/bits/std_locale.h <==
// Locale support -*- C++ -*-

// Copyright (C) 1997-1999 Cygnus Solutions
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

//
// ISO C++ 14882: 22.1  Locales
//

#ifndef _CPP_LOCALE
#define _CPP_LOCALE	1

#include <bits/c++config.h>  /* C++ Compiler characteristics */
#include <bits/stl_config.h> 
#include <bits/std_climits.h>
#include <bits/std_cstddef.h>  /* size_t */
#include <bits/std_exception.h>
#include <bits/std_ios.h>
#include <bits/std_iterator.h>
#include <bits/std_cwchar.h>
#include <bits/std_memory.h>
#include <bits/stl_string_fwd.h>
#include <bits/char_traits.h>
#include <bits/basic_string.h>      /* but not <bits/basic_string.tcc> */
#include <bits/std_stdexcept.h>
//#include <bits/std_vector.h>
#include <bits/std_cctype.h>
#include <bits/std_typeinfo.h> /* for bad_cast */
#include <bits/loccore.h>

#include <bits/std_ctime.h>
#include <bits/ios_base.h>
#include <bits/std_iterator.h>
#include <bits/locfacets.h>

#ifdef _G_NO_TEMPLATE_EXPORT
# define export
# include <bits/std_limits.h>  // numeric_limits<unsigned long>::digits10
# include <bits/std_stdexcept.h>
# include <bits/std_istream.h>
//# include <bits/loccore.tcc>
//# include <bits/locfacets.tcc>
# include <bits/string.tcc>
#endif

#endif

// Local Variables:
// mode:c++
// End:
